@@ -5,7 +5,7 @@ Copyright (C) Xavier Roche and other contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
+as published by the Free Software Foundation; either version 3
 of the License, or any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -174,6 +174,8 @@ const char* hts_optalias[][4] = {
   {"dos83","-L0","single",""},
   {"iso9660","-L2","single",""},
   {"disable-module","-%w","param1",""},
+  {"no-background-on-suspend","-y0","single",""},
+  {"background-on-suspend","-y","single",""},
   /* */
 
   /* DEPRECATED */
