@@ -5,7 +5,7 @@ Copyright (C) Xavier Roche and other contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
+as published by the Free Software Foundation; either version 3
 of the License, or any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -489,7 +489,7 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
           fprintf(opt->log,"An aborted mirror has been detected!\nThe current temporary cache is required for any update operation and only contains data downloaded during the last aborted session.\nThe former cache might contain more complete information; if you do not want to lose that information, you have to restore it and delete the current cache.\nThis can easily be done here by erasing the hts-cache/new.* files\n");
           fprintf(opt->log,"Please restart HTTrack with --continue (-iC1) option to override this message!\n");
         }
-        exit(0);
+        return 0;
       }
     }
   }
@@ -742,10 +742,6 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
       }
       
     } else {    // aucune URL dfinie et pas de cache
-      //if (argc > 1 && strcmp(argv[1], "-#h") == 0) {
-      //  printf("HTTrack version "HTTRACK_VERSION"%s\n", hts_get_version_info(opt));
-      //  exit(0);
-      //}
       if (opt->quiet) {
         help(argv[0],!opt->quiet);
         htsmain_free();
@@ -971,6 +967,8 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
             //
           case 'X': opt->delete_old=1; if (*(com+1)=='0') { opt->delete_old=0; com++; } break;
             //
+          case 'y': opt->background_on_suspend=1; if (*(com+1)=='0') { opt->background_on_suspend=0; com++; } break;
+            //
           case 'b': sscanf(com+1,"%d",&opt->accept_cookie); while(isdigit((unsigned char)*(com+1))) com++; break;
             //
           case 'N':
@@ -1714,7 +1712,7 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
             /* autotest */
             case 't':     /* not yet implemented */
               fprintf(stderr, "** AUTOCHECK OK\n");
-              exit(0);
+              return 0;
               break;
 
             default: printf("Internal option %c not recognized\n",*com); break;
@@ -2181,6 +2179,7 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
 
     // Lancement du miroir
     // ------------------------------------------------------------
+    opt->state._hts_in_mirror = 1;
     if (httpmirror(url, opt)==0) {
       printf("Error during operation (see log file), site has not been successfully mirrored\n");
     } else {
@@ -2192,6 +2191,7 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
         printf("Done.\n");
       }
     }
+    opt->state._hts_in_mirror = 0;
     // ------------------------------------------------------------
 
     //
