@@ -5,7 +5,7 @@ Copyright (C) Xavier Roche and other contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
+as published by the Free Software Foundation; either version 3
 of the License, or any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -262,7 +262,7 @@ void help_wizard(httrackp* opt) {
       linput(stdin,str,250);
       if (strnotempty(str)) {
         if (!((str[0]=='y') || (str[0]=='Y')))
-          exit(0);
+          return 0;
       }
       printf("\n");
 
@@ -461,7 +461,7 @@ void help(char* app,int more) {
   infomsg(" %D  cached delayed type check, don't wait for remote type during updates, to speedup them (%D0 wait, * %D1 don't wait)");
   infomsg(" %M  generate a RFC MIME-encapsulated full-archive (.mht)");
   infomsg("  LN long names (L1 *long names / L0 8-3 conversion / L2 ISO9660 compatible)");
-  infomsg("  KN keep original links (e.g. http://www.adr/link) (K0 *relative link, K absolute links, K4 original links, K3 absolute URI links)");
+  infomsg("  KN keep original links (e.g. http://www.adr/link) (K0 *relative link, K absolute links, K4 original links, K3 absolute URI links, K5 transparent proxy link)");
   infomsg("  x  replace external html links by error pages");
   infomsg(" %x  do not include any password for external password protected websites (%x0 include)");
   infomsg(" %q *include query string for local files (useless, for information purpose only) (%q0 don't include)");
@@ -587,6 +587,7 @@ void help(char* app,int more) {
   infomsg("  '%h' Host name (ex: www.someweb.com)");
   infomsg("  '%M' URL MD5 (128 bits, 32 ascii bytes)");
   infomsg("  '%Q' query string MD5 (128 bits, 32 ascii bytes)");
+  infomsg("  '%k' full query string");
   infomsg("  '%r' protocol name (ex: http)");
   infomsg("  '%q' small query string MD5 (16 bits, 4 ascii bytes)");
   infomsg("     '%s?' Short name version (ex: %sN)");
@@ -604,8 +605,9 @@ void help(char* app,int more) {
   infomsg("Details: Option K");
   infomsg("  K0  foo.cgi?q=45  ->  foo4B54.html?q=45 (relative URI, default)");
   infomsg("  K                 ->  http://www.foobar.com/folder/foo.cgi?q=45 (absolute URL)");
-  infomsg("  K4                ->  foo.cgi?q=45 (original URL)");
   infomsg("  K3                ->  /folder/foo.cgi?q=45 (absolute URI)");
+  infomsg("  K4                ->  foo.cgi?q=45 (original URL)");
+  infomsg("  K5                ->  http://www.foobar.com/folder/foo4B54.html?q=45 (transparent proxy URL)");
   infomsg("");
   infomsg("Shortcuts:");
   infomsg("--mirror      <URLs> *make a mirror of site(s) (default)");
