@@ -5,7 +5,7 @@ Copyright (C) Xavier Roche and other contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
+as published by the Free Software Foundation; either version 3
 of the License, or any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -102,6 +102,23 @@ static const char *hts_tbdev[] =
   opt->state._hts_in_html_parsing = prev; \
 } while(0)
 
+/* Strip all // */
+static void cleanDoubleSlash(char *s) {
+  int i, j;
+  for(i = 0, j = 0 ; s[i] != '\0' ; i++) {
+    if (s[i] == '/' && i != 0 && s[i - 1] == '/') {
+      continue;
+    }
+    if (i != j) {
+      s[j] = s[i];
+    }
+    j++;
+  }
+  if (i != j) {
+    s[j] = s[i];
+  }
+}
+
 
 // forme le nom du fichier  sauver (save)  partir de fil et adr
 // systme intelligent, qui renomme en cas de besoin (exemple: deux INDEX.HTML et index.html)
@@ -1198,7 +1215,8 @@ int url_savename(char* adr_complete, char* fil_complete, char* save,
   //
   { // liminer les // (comme ftp://)
     char* a;
-    while( (a=strstr(save,"//")) ) *a='_';
+    //while( (a=strstr(save,"//")) ) *a='_';
+    cleanDoubleSlash(save);
     // Eliminer chars spciaux
     a=save -1 ;
     while(*(++a))
