@@ -5,7 +5,7 @@ Copyright (C) Xavier Roche and other contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
+as published by the Free Software Foundation; either version 3
 of the License, or any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -222,6 +222,7 @@ struct htsoptstate {
 	int _hts_in_html_done;
 	int _hts_in_html_poll;
 	int _hts_setpause;
+	int _hts_in_mirror;
 	char** _hts_addurl;
   int _hts_cancel;
   htsoptstatecancel *cancel;            /* 3.41 */
@@ -357,6 +358,7 @@ struct httrackp {
   int quiet;            // poser des questions autres que wizard?
   int keyboard;         // vrifier stdin
   int bypass_limits;    // bypass built-in limits
+  int background_on_suspend;	// background process on suspend signal
   //
   int is_update;        // c'est une update (afficher "File updated...")
   int dir_topindex;     // reconstruire top index par la suite
